Learn R Programming

icesTAF (version 3.1-1)

read.taf: Read TAF Table from File

Description

Read a TAF table from a file into a data frame.

Usage

read.taf(file, check.names = FALSE, stringsAsFactors = FALSE,
  fileEncoding = "UTF-8", ...)

Arguments

file

a filename.

check.names

whether to enforce regular column names, e.g. convert column name "3" to "X3".

stringsAsFactors

whether to import strings as factors.

fileEncoding

character encoding of input file.

…

passed to read.csv.

Value

A data frame in TAF format, or a list of data frames if file is a directory or a vector of filenames.

Details

Alternatively, file can be a directory or a vector of filenames, to read many tables in one call.

See Also

read.csv is the underlying function used to read a table from a file.

write.taf writes a TAF table to a file.

icesTAF-package gives an overview of the package.

Examples

Run this code
# NOT RUN {
write.taf(catage.taf, "catage.csv")
catage <- read.taf("catage.csv")

write.taf(catage)
file.remove("catage.csv")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab